==> home-made-io-fastmag-sync-m2-0.25.0-3b5902.zip: Process/Entity/ToFastmag/Customer.php <==
<?php
/*******************************************************************************
 * Created by HOMEMADE.IO SAS.
 * Fastmag Sync  -  Connect Fastmag with your Magento
 *
 * Copyright (C) HOMEMADE.IO SAS, Inc - All Rights Reserved
 *
 * @author    Simon Laubet-Xavier <simon.laubetxavier@home-made.io>
 * @copyright 2020-2021 HOMEMADE.IO SAS
 * @date      2021-10-26
 ******************************************************************************/

namespace Fastmag\Sync\Process\Entity\ToFastmag;

use DateTime;
use Exception;
use Fastmag\Sync\Process\EntityInterface;
use Fastmag\Sync\Process\Entity\Helper\Attribute\Gender;
use Fastmag\Sync\Process\Entity\Helper\Attribute\Prefix;
use IntlDateFormatter;
use Magento\Framework\DataObject;

/**
 * Class Customer
 *
 * Entity class for customer.
 * Save and transform data from Magento for Fastmag easy integration,
 * and transfer it from hydration worker to integration worker
 *
 * @method int|null getMagentoId()
 * @method int|null getFastmagId()
 * @method int|null getStoreId()
 * @method string|null getFirstname()
 * @method string|null getLastname()
 * @method Address|null getBillingAddress()
 * @method Address|null getShippingAddress()
 * @method Customer setMagentoId(int $magentoId)
 * @method Customer setFastmagId(int $fastmagId)
 * @method Customer setStoreId(int $storeId)
 * @method Customer setGender(int $gender)
 * @method Customer setPrefix(string $prefix)
 * @method Customer setFirstname(string $firstname)
 * @method Customer setLastname(string $lastname)
 * @method Customer setEmailAddress(string $emailAddress)
 * @method Customer setSubscribeNewsletter(bool $subscribeNewsletter)
 * @method Customer setBillingAddress(Address $address)
 * @method Customer setShippingAddress(Address $address)
 */
class Customer extends DataObject implements EntityInterface
{
    /** @var IntlDateFormatter $dateFormatter */
    protected $dateFormatter;

    /**
     * Customer constructor.
     *
     * @param array $data
     */
    public function __construct(array $data = [])
    {
        parent::__construct($data);

        $this->dateFormatter = new IntlDateFormatter(
            'fr_FR',
            IntlDateFormatter::SHORT,
            IntlDateFormatter::NONE,
            'Europe/Paris',
            IntlDateFormatter::GREGORIAN,
            'dd/MM/yyyy'
        );
    }

    /**
     * Get gender
     *
     * @return string|null
     */
    public function getGender()
    {
        return $this->getData('gender') !== null ? Gender::getFastmagValue($this->getData('gender')) : null;
    }

    /**
     * Get prefix
     *
     * @return string
     */
    public function getPrefix()
    {
        return $this->getData('prefix') !== null ?
            Prefix::getFastmagValue($this->getData('prefix')) : Prefix::getDefaultFastmagValue();
    }

    /**
     * Get email address
     *
     * @return string
     */
    public function getEmailAddress()
    {
        return $this->getData('email_address') !== null ? strtolower($this->getData('email_address')) : null;
    }

    /**
     * Get date of birth
     *
     * @return string|null
     */
    public function getDob()
    {
        $result = null;

        $dob = $this->getData('dob');

        if (!empty($dob) && !($dob instanceof DateTime)) {
            try {
                $this->setData('dob', new DateTime($dob));

                $result = $this->dateFormatter->format($this->getData('dob'));
            } catch (Exception $exception) {
                // Do nothing
            }
        }

        return $result;
    }

    /**
     * Get if the customer is a subscriber of the newsletter
     *
     * @return bool|null
     */
    public function getSubscribeNewsletter()
    {
        return $this->getData('subscribe_newsletter') !== null ? (bool)$this->getData('subscribe_newsletter') : null;
    }

    /**
     * Set DOB
     *
     * @param string $dob
     *
     * @return Customer
     *
     * @throws Exception
     */
    public function setDob($dob)
    {
        return $this->setData('dob', new DateTime($dob));
    }

    /**
     * @inheritDoc
     */
    public function export()
    {
        $result = [
            'magento_id'       => $this->getMagentoId(),
            'fastmag_id'       => $this->getFastmagId(),
            'store_id'         => $this->getStoreId(),
            'gender'           => $this->getGender(),
            'prefix'           => $this->getPrefix(),
            'firstname'        => $this->getFirstname(),
            'lastname'         => $this->getLastname(),
            'email_address'    => $this->getEmailAddress(),
            'dob'              => $this->getDob(),
            'subscribe_nl'     => $this->getSubscribeNewsletter(),
            'billing_address'  => ($this->getBillingAddress() ? $this->getBillingAddress()->export() : null),
            'shipping_address' => ($this->getShippingAddress() ? $this->getShippingAddress()->export() : null)
        ];

        return array_filter(
            $result,
            static function ($value) {
                return $value !== null && $value !== [];
            }
        );
    }
}

==> home-made-io-fastmag-sync-m2-1.9.0-b17085.zip: Process/Entity/ToFastmag/Customer.php <==
<?php
/*******************************************************************************
 * Created by HOMEMADE.IO SAS.
 * Fastmag Sync  -  Connect Fastmag with your Magento
 *
 * Copyright (C) HOMEMADE.IO SAS, Inc - All Rights Reserved
 *
 * @author    Simon Laubet-Xavier <simon.laubetxavier@home-made.io>
 * @copyright 2020-2024 HOMEMADE.IO SAS
 * @date      2024-06-18
 ******************************************************************************/

namespace Fastmag\Sync\Process\Entity\ToFastmag;

use DateTime;
use Exception;
use Fastmag\Sync\Process\Entity\Date as DateTrait;
use Fastmag\Sync\Process\EntityInterface;
use Fastmag\Sync\Process\Entity\Helper\Attribute\Gender;
use Fastmag\Sync\Process\Entity\Helper\Attribute\Prefix;
use Fastmag\Sync\Process\Entity\ToFastmag\AddressFactory as AddressEntityFactory;
use Magento\Framework\DataObject;

/**
 * Class Customer
 *
 * Entity class for customer.
 * Save and transform data from Magento for Fastmag easy integration,
 * and transfer it from hydration worker to integration worker
 *
 * @method int|null getMagentoId()
 * @method int|null getFastmagId()
 * @method int|null getStoreId()
 * @method Address|null getBillingAddress()
 * @method Address|null getShippingAddress()
 * @method Customer setMagentoId(int $magentoId)
 * @method Customer setFastmagId(int $fastmagId)
 * @method Customer setStoreId(int $storeId)
 * @method Customer setGender(int $gender)
 * @method Customer setPrefix(string $prefix)
 * @method Customer setFirstname(string $firstname)
 * @method Customer setLastname(string $lastname)
 * @method Customer setEmailAddress(string $emailAddress)
 * @method Customer setSubscribeNewsletter(bool $subscribeNewsletter)
 * @method Customer setBillingAddress(Address $address)
 * @method Customer setShippingAddress(Address $address)
 */
class Customer extends DataObject implements EntityInterface
{
    use DateTrait;

    /** @var AddressEntityFactory $addressEntityFactory */
    protected $addressEntityFactory;

    /**
     * Customer constructor.
     *
     * @param AddressEntityFactory $addressEntityFactory
     * @param array $data
     */
    public function __construct(AddressEntityFactory $addressEntityFactory, array $data = [])
    {
        parent::__construct($data);

        $this->addressEntityFactory = $addressEntityFactory;

        if (array_key_exists('billing_address', $data)) {
            $billingAddress = $this->addressEntityFactory->create(['data' => $data['billing_address']]);
            $this->setBillingAddress($billingAddress);
        }
        if (array_key_exists('shipping_address', $data)) {
            $shippingAddress = $this->addressEntityFactory->create(['data' => $data['shipping_address']]);
            $this->setShippingAddress($shippingAddress);
        }

        $this->timeZoneInput = 'UTC';
        $this->timeZoneOutput = 'Europe/Paris';

        $this->configureDateFormatter();
    }

    /**
     * Get gender
     *
     * @return string|null
     */
    public function getGender()
    {
        return $this->getData('gender') !== null
            ? Gender::getFastmagValue($this->getData('gender'))
            : Gender::getDefaultFastmagValue();
    }

    /**
     * Get prefix
     *
     * @return string
     */
    public function getPrefix()
    {
        return $this->getData('prefix') !== null
            ? Prefix::getFastmagValue($this->getData('prefix'))
            : Prefix::getDefaultFastmagValue();
    }

    /**
     * Get firstname
     *
     * @return string
     */
    public function getFirstname()
    {
        return $this->getData('firstname') !== null ? strtoupper($this->getData('firstname')) : null;
    }

    /**
     * Get lastname
     *
     * @return string
     */
    public function getLastname()
    {
        return $this->getData('lastname') !== null ? strtoupper($this->getData('lastname')) : null;
    }

    /**
     * Get email address
     *
     * @return string|null
     */
    public function getEmailAddress(): ?string
    {
        return $this->getData('email_address') !== null ? strtolower($this->getData('email_address')) : null;
    }

    /**
     * Get date of birth
     *
     * @return string|null
     */
    public function getDob(): ?string
    {
        return $this->getFormattedDate('dob', 'dd/MM/y');
    }

    /**
     * Get if the customer is a subscriber of the newsletter
     *
     * @return bool|null
     */
    public function getSubscribeNewsletter()
    {
        return $this->getData('subscribe_newsletter') !== null ? (bool)$this->getData('subscribe_newsletter') : null;
    }

    /**
     * Set DOB
     *
     * @param string $dob
     *
     * @return Customer
     *
     * @throws Exception
     */
    public function setDob($dob)
    {
        if ($dob !== null) {
            $this->setData('dob', new DateTime($dob));
        }

        return $this;
    }

    /**
     * @inheritDoc
     */
    public function export()
    {
        $result = [
            'magento_id'       => $this->getMagentoId(),
            'fastmag_id'       => $this->getFastmagId(),
            'store_id'         => $this->getStoreId(),
            'gender'           => $this->getGender(),
            'prefix'           => $this->getPrefix(),
            'firstname'        => $this->getFirstname(),
            'lastname'         => $this->getLastname(),
            'email_address'    => $this->getEmailAddress(),
            'dob'              => $this->getDob(),
            'subscribe_nl'     => $this->getSubscribeNewsletter(),
            'billing_address'  => ($this->getBillingAddress() ? $this->getBillingAddress()->export() : null),
            'shipping_address' => ($this->getShippingAddress() ? $this->getShippingAddress()->export() : null)
        ];

        return array_filter(
            $result,
            static function ($value) {
                return $value !== null && $value !== [];
            }
        );
    }
}
